# Graph GA

Note: most code here was copied directly from [Guacamol baselines](https://github.com/BenevolentAI/guacamol_baselines)
Much of the code was kept the same, but the outer GA loop was written from scratch.
